@@ -69,8 +69,8 @@ def check_fed_model(save_dir,keys,test_acc=None,test_loss=None,EpochCount=None):
             model=torch.load(os.path.join(save_dir,key))
             cmodels.append(model)
         result=3
-    except:
-        pass
+    except Exception as es:
+        print(es)
     if result==3:
         avg_model=average_weights(cmodels)
         if avg_model:
